@@ -3,7 +3,7 @@ from pathlib import Path
 from collections import defaultdict
 from json import loads, load, dump
 from uuid import uuid4
-from typing import Dict, List, Tuple, Any, Callable, Generic, Union, overload
+from typing import Dict, List, Tuple, Any, Callable, Generic, Union, cast
 from ..common import (
     T, R, L, Domain, Filterer, DefaultFilterer,
     Locator, DefaultLocator, Editor, DefaultEditor)
@@ -14,13 +14,13 @@ class JsonRepository(Repository, Generic[T]):
     def __init__(self,
                  data_path: str,
                  collection: str,
-                 item_class: Callable[..., T],
+                 constructor: Callable[..., T],
                  filterer: Filterer = None,
                  locator: Locator = None,
                  editor: Editor = None) -> None:
         self.data_path = data_path
         self.collection = collection
-        self.item_class: Callable[..., T] = item_class
+        self.constructor: Callable[..., T] = constructor
         self.filterer = filterer or DefaultFilterer()
         self.locator = locator or DefaultLocator()
         self.editor = editor or DefaultEditor()
@@ -80,36 +80,14 @@ class JsonRepository(Repository, Generic[T]):
         domain = domain or []
         filter_function = self.filterer.parse(domain)
         for item_dict in list(data[self.collection].values()):
-            item = self.item_class(**item_dict)
+            item = self.constructor(**item_dict)
             if filter_function(item):
                 count += 1
         return count
 
-    @overload
-    async def search(self, domain: Domain,
-                     limit: int = None, offset: int = None) -> List[T]:
-        """Standard search method"""
-
-    @overload
     async def search(self, domain: Domain,
                      limit: int = None, offset: int = None,
-                     *,
-                     join: 'Repository[R]',
-                     link: 'Repository[L]' = None,
-                     source: str = None,
-                     target: str = None) -> List[Tuple[T, List[R]]]:
-        """Joining search method"""
-
-    async def search(
-            self, domain: Domain,
-            limit: int = None,
-            offset: int = None,
-            *,
-            join: 'Repository[R]' = None,
-            link: 'Repository[L]' = None,
-            source: str = None,
-            target: str = None) -> Union[List[T], List[Tuple[T, List[R]]]]:
-
+                     order: str = None) -> List[T]:
         items: List[T] = []
         if not self.file_path.exists():
             return items
@@ -120,7 +98,7 @@ class JsonRepository(Repository, Generic[T]):
 
         filter_function = self.filterer.parse(domain)
         for item_dict in items_dict.values():
-            item = self.item_class(**item_dict)
+            item = self.constructor(**item_dict)
 
             if filter_function(item):
                 items.append(item)
@@ -129,39 +107,15 @@ class JsonRepository(Repository, Generic[T]):
             items = items[offset:]
         if limit is not None:
             items = items[:limit]
+        if order:
+            fields = order.lower().split(',')
+            for field in reversed(fields):
+                key, *direction = field.split()
+                items = cast(List[T], sorted(
+                    items, key=lambda item: getattr(item, key),
+                    reverse=('desc' in direction)))
 
-        if not join:
-            return items
-
-        reference = (link == self) and join or self
-        source = source or f'{reference.model.__name__.lower()}_id'
-        pivot = link and link not in (self, join)
-
-        field, key = source, 'id'
-        if reference is join:
-            field, key = key, source
-
-        entries: Union[List[T], List[L]] = items
-        if pivot and link:
-            entries = await link.search([
-                (field, 'in', [getattr(entry, key) for entry in entries])])
-            target = target or f'{join.model.__name__.lower()}_id'
-            field, key = 'id', target
-
-        record_map = defaultdict(list)
-        for record in await join.search([
-                (field, 'in', [getattr(entry, key) for entry in entries])]):
-            record_map[getattr(record, field)].append(record)
-
-        relation_map = record_map
-        if pivot:
-            relation_map = defaultdict(list)
-            for entry in entries:
-                relation_map[getattr(entry, source)].extend(
-                    record_map[getattr(entry, key)])
-            field, key = source, 'id'
-
-        return [(item, relation_map[getattr(item, key)]) for item in items]
+        return items
 
     @property
     def file_path(self) -> Path:
